summaryrefslogtreecommitdiffstats
path: root/tests/auto/tools/uic/tst_uic.cpp
diff options
context:
space:
mode:
authorFriedemann Kleint <Friedemann.Kleint@qt.io>2020-12-04 11:14:27 +0100
committerFriedemann Kleint <Friedemann.Kleint@qt.io>2020-12-04 11:30:10 +0100
commitfc9cda5f08ac848e88f63dd4a07c08b2fbc6bf17 (patch)
tree8d3adebbc24ee255c14662d040047242276dbfc9 /tests/auto/tools/uic/tst_uic.cpp
parentb2ebc2268c1a4093b0771c92e53732a1ad332f1c (diff)
Fix uic/rcc generating outdated export for Qt for Pythonv6.0.0
Bump version to 6. Pick-to: dev 6.0 Fixes: QTBUG-89124 Change-Id: Ifcf60552b5b6efb86f79da34da9c34b8efae9fa4 Reviewed-by: Cristian Maureira-Fredes <cristian.maureira-fredes@qt.io>
Diffstat (limited to 'tests/auto/tools/uic/tst_uic.cpp')
-rw-r--r--tests/auto/tools/uic/tst_uic.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/tests/auto/tools/uic/tst_uic.cpp b/tests/auto/tools/uic/tst_uic.cpp
index 07e508997d..0a07948dc2 100644
--- a/tests/auto/tools/uic/tst_uic.cpp
+++ b/tests/auto/tools/uic/tst_uic.cpp
@@ -117,7 +117,7 @@ static QByteArray msgProcessStartFailed(const QString &command, const QString &w
return result.toLocal8Bit();
}
// Locate Python and check whether PySide2 is installed
static QString locatePython(QTemporaryDir &generatedDir)
{
QString python = QStandardPaths::findExecutable(QLatin1String("python"));
@@ -128,7 +128,7 @@ static QString locatePython(QTemporaryDir &generatedDir)
QFile importTestFile(generatedDir.filePath(QLatin1String("import_test.py")));
if (!importTestFile.open(QIODevice::WriteOnly| QIODevice::Text))
return QString();
- importTestFile.write("import PySide2.QtCore\n");
+ importTestFile.write("import PySide6.QtCore\n");
importTestFile.close();
QProcess process;
process.start(python, {importTestFile.fileName()});
@@ -136,7 +136,7 @@ static QString locatePython(QTemporaryDir &generatedDir)
return QString();
if (process.exitStatus() != QProcess::NormalExit || process.exitCode() != 0) {
const QString stdErr = QString::fromLocal8Bit(process.readAllStandardError()).simplified();
- qWarning("PySide2 is not installed (%s)", qPrintable(stdErr));
+ qWarning("PySide6 is not installed (%s)", qPrintable(stdErr));
return QString();
}
importTestFile.remove();
@@ -117,7 +117,7 @@ static QByteArray msgProcessStartFailed(const QString &command, const QString &w
return result.toLocal8Bit();
}
-// Locate Python and check whether PySide2 is installed
+// Locate Python and check whether PySide6 is installed
static QString locatePython(QTemporaryDir &generatedDir)
{